@@ -5,8 +5,8 @@ except ImportError:
 
 
 from ._reader import napari_get_reader
-from ._function2 import napari_experimental_provide_function
-#from ._dock_widget import napari_experimental_provide_dock_widget
+#from ._function2 import napari_experimental_provide_function
+from ._dock_widget import napari_experimental_provide_dock_widget
 #from ._summary import napari_experimental_provide_function
 #from ._function import napari_experimental_provide_function
 
